# Modules to calculate/process stresses

## Contents

### Equivalent stresses

`equistress.py` includes routines to calculate equivalent stresses

* von Mises
* signed von Mises
* Tresca
* first principle stress
* absolute first principle stress
